pub struct NonEmptyString(/* private fields */);Expand description
A string that is guaranteed to contain at least one element.
NonEmptyString provides a safe wrapper around String that maintains the invariant
that the string can never be empty.
Examples
use non_non_full::NonEmptyString;
let string = "Hello, World!".to_owned();
let non_empty = NonEmptyString::new(string).unwrap();
// Empty String returns None
assert!(NonEmptyString::new(String::new()).is_none());Implementations
Sourceimpl NonEmptyString
impl NonEmptyString
Sourcepub fn new(string: String) -> Option<Self>
pub fn new(string: String) -> Option<Self>
Creates a new NonEmptyString from a String.
Returns None if the input String is empty.
Sourcepub fn into_string(self) -> String
pub fn into_string(self) -> String
Converts the NonEmptyString back into a String, consuming self
Sourcepub fn insert_str(&mut self, idx: usize, string: &str)
pub fn insert_str(&mut self, idx: usize, string: &str)
Inserts a string slice at the given byte index
Sourcepub fn remove(&mut self, idx: usize) -> Option<char>
pub fn remove(&mut self, idx: usize) -> Option<char>
Removes the char at the given byte index.
Returns None if removing would make the string empty.
Sourcepub fn pop(&mut self) -> Option<char>
pub fn pop(&mut self) -> Option<char>
Removes the last char from the string.
Returns None if this would make the string empty.
Sourcepub fn clear_except_first(&mut self)
pub fn clear_except_first(&mut self)
Clears all chars except the first one
Sourcepub fn char_indices(&self) -> CharIndices<'_>
pub fn char_indices(&self) -> CharIndices<'_>
Returns an iterator over the char indices in the string